Index: webrtc/media/base/testutils.cc |
diff --git a/talk/media/base/testutils.cc b/webrtc/media/base/testutils.cc |
similarity index 97% |
rename from talk/media/base/testutils.cc |
rename to webrtc/media/base/testutils.cc |
index 49a78e63ddca904793544891186e034010e3a9cd..683b5cff7393d34dda24025c477e5d5fbaca7644 100644 |
--- a/talk/media/base/testutils.cc |
+++ b/webrtc/media/base/testutils.cc |
@@ -25,15 +25,11 @@ |
* ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
*/ |
-#include "talk/media/base/testutils.h" |
+#include "webrtc/media/base/testutils.h" |
#include <math.h> |
#include <algorithm> |
-#include "talk/media/base/executablehelpers.h" |
-#include "talk/media/base/rtpdump.h" |
-#include "talk/media/base/videocapturer.h" |
-#include "talk/media/base/videoframe.h" |
#include "webrtc/base/bytebuffer.h" |
#include "webrtc/base/fileutils.h" |
#include "webrtc/base/gunit.h" |
@@ -41,6 +37,10 @@ |
#include "webrtc/base/stream.h" |
#include "webrtc/base/stringutils.h" |
#include "webrtc/base/testutils.h" |
+#include "webrtc/media/base/executablehelpers.h" |
+#include "webrtc/media/base/rtpdump.h" |
+#include "webrtc/media/base/videocapturer.h" |
+#include "webrtc/media/base/videoframe.h" |
namespace cricket { |
@@ -258,18 +258,18 @@ void VideoCapturerListener::OnFrameCaptured(VideoCapturer* capturer, |
} |
} |
// Returns the absolute path to a file in the testdata/ directory. |
std::string GetTestFilePath(const std::string& filename) { |
// Locate test data directory. |
#ifdef ENABLE_WEBRTC |
rtc::Pathname path = rtc::GetExecutablePath(); |
EXPECT_FALSE(path.empty()); |
- path.AppendPathname("../../talk/"); |
+ path.AppendPathname("../../resources/"); |
#else |
rtc::Pathname path = testing::GetTalkDirectory(); |
EXPECT_FALSE(path.empty()); // must be run from inside "talk" |
#endif |
- path.AppendFolder("media/testdata/"); |
+ path.AppendFolder("media/"); |
path.SetFilename(filename); |
return path.pathname(); |
} |
@@ -258,18 +258,18 @@ void VideoCapturerListener::OnFrameCaptured(VideoCapturer* capturer, |
} |
} |
-// Returns the absolute path to a file in the testdata/ directory. |
+// Returns the absolute path to a file in the resources/ directory. |
std::string GetTestFilePath(const std::string& filename) { |
// Locate test data directory. |